# SPDX-License-Identifier: Apache-2.0
# Licensed to the Ed-Fi Alliance under one or more agreements.
# The Ed-Fi Alliance licenses this file to you under the Apache License, Version 2.0.
# See the LICENSE and NOTICES files in the project root for more information.

LOG_LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]


class SOURCE_SYSTEM:
    GOOGLE = "Google"
    SCHOOLOGY = "Schoology"
    CANVAS = "Canvas"


class SOURCE_SYSTEM_NAMESPACE:
    GOOGLE = "uri://google.com/classroom"
    SCHOOLOGY = "uri://schoology.com"
    CANVAS = "uri://instructure.com/canvas"


class DB_ENGINE:
    MSSQL = "mssql"
    POSTGRESQL = "postgresql"
